#
# spec file for package python-pyrad
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyrad
Version:        2.4
Release:        3.12
Summary:        RADIUS tools
License:        BSD-3-Clause
URL:            https://github.com/pyradius/pyrad
Source0:        https://github.com/pyradius/pyrad/archive/%{version}.tar.gz
BuildRequires:  %{python_module netaddr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  netcfg libnss_usrfiles2
BuildRequires:  python-rpm-macros
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
pyrad is an implementation of a RADIUS client/server as described in RFC2865.
It takes care of all the details like building RADIUS packets, sending
them and decoding responses.

%prep
%setup -q -n pyrad-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add missing six dependency declaration
* Sun Jun 13 2021 Michael Ströder <michael@stroeder.com>
- Use %%pyunittest, dropped build dependency on pytest
* Wed Dec 16 2020 Michael Ströder <michael@stroeder.com>
- Fixed glob-pattern for tests
- Update to version 2.4
  * Support poetry for building this project
  * Use secrets.SysRandom instead of random.SystemRandom if possible
  * .get on Packets has an optional default parameter (to mimic dict.get())
  * Fix: digestmod is not optional in python3.8 anymore
  * Fix: authenticator was refreshed before the packet was generated
  * Fix bug causing Message-Authenticator verification to fail if
    multiple instances of an attribute do not appear sequentially in
    the attributes list
  * Fixed #140 VerifyReply broken when multiple instances of same attribute are
    not adjacent on reply
  * Fixed #135 Missing send_packet for async Client
  * Fixed #126 python3 support for SaltCrypt (was previously broken)
* Wed Jun 17 2020 pgajdos@suse.com
- nose -> pytest
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.3
  * Fixed #124 remove reuse_address=True from async server/client
  * Fixed #121 Unknown attribute key error
* Mon Nov  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball
- Run tests by just invoking nosetests
* Fri Nov  1 2019 Boris Manojlovic <boris@steki.net>
- added test-data.tar.gz extracted from git repository
  https://github.com/pyradius/pyrad
* Thu Oct 31 2019 Boris Manojlovic <boris@steki.net>
- initial packaging of version 2.2
